# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/quant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/rules/quant.proto\x12\x1fpro.omni.oms.api.v1.rules.quant\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xf8\x01\n\x05Quant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0eproduct_doc_id\x18\x02 \x01(\t\x12\x17\n\x0flocation_sql_id\x18\x03 \x01(\x05\x12\x14\n\x0cquant_sql_id\x18\x04 \x01(\x05\x12\x1a\n\x12\x61vailable_quantity\x18\x05 \x01(\x02\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc4\x01\n\x12QuantCreateRequest\x12\x16\n\x0eproduct_doc_id\x18\x01 \x01(\t\x12\x17\n\x0flocation_sql_id\x18\x02 \x01(\x05\x12\x14\n\x0cquant_sql_id\x18\x03 \x01(\x05\x12\x1a\n\x12\x61vailable_quantity\x18\x04 \x01(\x02\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantCreateResponse\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.rules.quant.Quant\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xee\x02\n\x10QuantReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11QuantReadResponse\x12\x36\n\x06quants\x18\x01 \x03(\x0b\x32&.pro.omni.oms.api.v1.rules.quant.Quant\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x83\x01\n\x12QuantUpdateRequest\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.rules.quant.Quant\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantUpdateResponse\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.rules.quant.Quant\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"b\n\x12QuantDeleteRequest\x12\x14\n\x0cquant_sql_id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13QuantDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cQuantService\x12z\n\x0bQuantCreate\x12\x33.pro.omni.oms.api.v1.rules.quant.QuantCreateRequest\x1a\x34.pro.omni.oms.api.v1.rules.quant.QuantCreateResponse"\x00\x12t\n\tQuantRead\x12\x31.pro.omni.oms.api.v1.rules.quant.QuantReadRequest\x1a\x32.pro.omni.oms.api.v1.rules.quant.QuantReadResponse"\x00\x12z\n\x0bQuantUpdate\x12\x33.pro.omni.oms.api.v1.rules.quant.QuantUpdateRequest\x1a\x34.pro.omni.oms.api.v1.rules.quant.QuantUpdateResponse"\x00\x12z\n\x0bQuantDelete\x12\x33.pro.omni.oms.api.v1.rules.quant.QuantDeleteRequest\x1a\x34.pro.omni.oms.api.v1.rules.quant.QuantDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.quant_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_QUANT"]._serialized_start = 109
    _globals["_QUANT"]._serialized_end = 357
    _globals["_QUANTCREATEREQUEST"]._serialized_start = 360
    _globals["_QUANTCREATEREQUEST"]._serialized_end = 556
    _globals["_QUANTCREATERESPONSE"]._serialized_start = 559
    _globals["_QUANTCREATERESPONSE"]._serialized_end = 710
    _globals["_QUANTREADREQUEST"]._serialized_start = 713
    _globals["_QUANTREADREQUEST"]._serialized_end = 1079
    _globals["_QUANTREADRESPONSE"]._serialized_start = 1082
    _globals["_QUANTREADRESPONSE"]._serialized_end = 1291
    _globals["_QUANTUPDATEREQUEST"]._serialized_start = 1294
    _globals["_QUANTUPDATEREQUEST"]._serialized_end = 1425
    _globals["_QUANTUPDATERESPONSE"]._serialized_start = 1428
    _globals["_QUANTUPDATERESPONSE"]._serialized_end = 1579
    _globals["_QUANTDELETEREQUEST"]._serialized_start = 1581
    _globals["_QUANTDELETEREQUEST"]._serialized_end = 1679
    _globals["_QUANTDELETERESPONSE"]._serialized_start = 1681
    _globals["_QUANTDELETERESPONSE"]._serialized_end = 1777
    _globals["_QUANTSERVICE"]._serialized_start = 1780
    _globals["_QUANTSERVICE"]._serialized_end = 2284
# @@protoc_insertion_point(module_scope)
