# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/export.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19v1/utilities/export.proto\x12$pro.omni.oms.api.v1.utilities.export\x1a\x11\x63ommon/base.proto"\x9d\x01\n\x12\x45xportModelRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x11\n\texport_to\x18\x02 \x01(\t\x12\x18\n\x10\x65xport_type_file\x18\x03 \x01(\t\x12\x0e\n\x06\x66ields\x18\x04 \x03(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13\x45xportModelResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x96\x01\n\rExportService\x12\x84\x01\n\x0b\x45xportModel\x12\x38.pro.omni.oms.api.v1.utilities.export.ExportModelRequest\x1a\x39.pro.omni.oms.api.v1.utilities.export.ExportModelResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.export_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_EXPORTMODELREQUEST"]._serialized_start = 87
    _globals["_EXPORTMODELREQUEST"]._serialized_end = 244
    _globals["_EXPORTMODELRESPONSE"]._serialized_start = 246
    _globals["_EXPORTMODELRESPONSE"]._serialized_end = 342
    _globals["_EXPORTSERVICE"]._serialized_start = 345
    _globals["_EXPORTSERVICE"]._serialized_end = 495
# @@protoc_insertion_point(module_scope)
