# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/import_export.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.utilities import model_pb2 as v1_dot_utilities_dot_model__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/utilities/import_export.proto\x12+pro.omni.oms.api.v1.utilities.import_export\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/utilities/model.proto"\xfa\x03\n\x0cImportExport\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0etype_operation\x18\x02 \x01(\t\x12\x39\n\x05model\x18\x03 \x01(\x0b\x32*.pro.omni.oms.api.v1.utilities.model.Model\x12\x11\n\tname_file\x18\x04 \x01(\t\x12\x11\n\ttype_file\x18\x05 \x01(\t\x12-\n\tdate_load\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x64\x61te_process\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x0f\n\x07message\x18\t \x01(\t\x12\x17\n\x0frequired_fields\x18\n \x03(\t\x12-\n\x0cprocess_data\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\nskip_error\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xcc\x02\n\x19ImportExportCreateRequest\x12\x16\n\x0etype_operation\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x11\n\tname_file\x18\x03 \x01(\t\x12\x11\n\ttype_file\x18\x04 \x01(\t\x12-\n\tdate_init\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x64\x61te_finish\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0frequired_fields\x18\x07 \x03(\t\x12.\n\nskip_error\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\t \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"\xf5\x02\n\x17ImportExportReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf2\x01\n\x18ImportExportReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12P\n\rimport_export\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"\xa5\x01\n\x19ImportExportUpdateRequest\x12P\n\rimport_export\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"_\n\x19ImportExportDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1aImportExportDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport"Z\n\x14\x43onfirmUploadRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb4\x01\n\x15\x43onfirmUploadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\rimport_export\x18\x02 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.utilities.import_export.ImportExport2\xd2\x06\n\x13ImportExportService\x12\xa7\x01\n\x12ImportExportCreate\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportCreateRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportCreateResponse"\x00\x12\xa1\x01\n\x10ImportExportRead\x12\x44.pro.omni.oms.api.v1.utilities.import_export.ImportExportReadRequest\x1a\x45.pro.omni.oms.api.v1.utilities.import_export.ImportExportReadResponse"\x00\x12\xa7\x01\n\x12ImportExportUpdate\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportUpdateRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportUpdateResponse"\x00\x12\xa7\x01\n\x12ImportExportDelete\x12\x46.pro.omni.oms.api.v1.utilities.import_export.ImportExportDeleteRequest\x1aG.pro.omni.oms.api.v1.utilities.import_export.ImportExportDeleteResponse"\x00\x12\x98\x01\n\rConfirmUpload\x12\x41.pro.omni.oms.api.v1.utilities.import_export.ConfirmUploadRequest\x1a\x42.pro.omni.oms.api.v1.utilities.import_export.ConfirmUploadResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.import_export_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_IMPORTEXPORT"]._serialized_start = 222
    _globals["_IMPORTEXPORT"]._serialized_end = 728
    _globals["_IMPORTEXPORTCREATEREQUEST"]._serialized_start = 731
    _globals["_IMPORTEXPORTCREATEREQUEST"]._serialized_end = 1063
    _globals["_IMPORTEXPORTCREATERESPONSE"]._serialized_start = 1066
    _globals["_IMPORTEXPORTCREATERESPONSE"]._serialized_end = 1251
    _globals["_IMPORTEXPORTREADREQUEST"]._serialized_start = 1254
    _globals["_IMPORTEXPORTREADREQUEST"]._serialized_end = 1627
    _globals["_IMPORTEXPORTREADRESPONSE"]._serialized_start = 1630
    _globals["_IMPORTEXPORTREADRESPONSE"]._serialized_end = 1872
    _globals["_IMPORTEXPORTUPDATEREQUEST"]._serialized_start = 1875
    _globals["_IMPORTEXPORTUPDATEREQUEST"]._serialized_end = 2040
    _globals["_IMPORTEXPORTUPDATERESPONSE"]._serialized_start = 2043
    _globals["_IMPORTEXPORTUPDATERESPONSE"]._serialized_end = 2228
    _globals["_IMPORTEXPORTDELETEREQUEST"]._serialized_start = 2230
    _globals["_IMPORTEXPORTDELETEREQUEST"]._serialized_end = 2325
    _globals["_IMPORTEXPORTDELETERESPONSE"]._serialized_start = 2328
    _globals["_IMPORTEXPORTDELETERESPONSE"]._serialized_end = 2513
    _globals["_CONFIRMUPLOADREQUEST"]._serialized_start = 2515
    _globals["_CONFIRMUPLOADREQUEST"]._serialized_end = 2605
    _globals["_CONFIRMUPLOADRESPONSE"]._serialized_start = 2608
    _globals["_CONFIRMUPLOADRESPONSE"]._serialized_end = 2788
    _globals["_IMPORTEXPORTSERVICE"]._serialized_start = 2791
    _globals["_IMPORTEXPORTSERVICE"]._serialized_end = 3641
# @@protoc_insertion_point(module_scope)
