# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/order.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.sales import address_pb2 as v1_dot_sales_dot_address__pb2
from omni.pro.protos.v1.sales import delivery_method_pb2 as v1_dot_sales_dot_delivery__method__pb2
from omni.pro.protos.v1.sales import sale_pb2 as v1_dot_sales_dot_sale__pb2
from omni.pro.protos.v1.sales import warehouse_pb2 as v1_dot_sales_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/sales/order.proto\x12\x1fpro.omni.oms.api.v1.sales.order\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16v1/sales/address.proto\x1a\x13v1/sales/sale.proto\x1a\x1ev1/sales/delivery_method.proto\x1a\x18v1/sales/warehouse.proto"\x89\x04\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x32\n\x04sale\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.v1.sales.sale.Sale\x12@\n\x0cship_address\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.address.Address\x12R\n\x0f\x64\x65livery_method\x18\x05 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12\x11\n\ttax_total\x18\x06 \x01(\x02\x12\x16\n\x0e\x64iscount_total\x18\x07 \x01(\x02\x12\x10\n\x08subtotal\x18\x08 \x01(\x02\x12\r\n\x05total\x18\t \x01(\x02\x12*\n\x06\x61\x63tive\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12\x41\n\twarehouse\x18\x0c \x01(\x0b\x32..pro.omni.oms.api.v1.sales.warehouse.Warehouse\x12\x0b\n\x03\x63id\x18\r \x01(\t\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa6\x02\n\x12OrderCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07sale_id\x18\x02 \x01(\x05\x12\x19\n\x11ship_address_code\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65livery_method_id\x18\x04 \x01(\x05\x12\x11\n\ttax_total\x18\x05 \x01(\x02\x12\x16\n\x0e\x64iscount_total\x18\x06 \x01(\x02\x12\x10\n\x08subtotal\x18\x07 \x01(\x02\x12\r\n\x05total\x18\x08 \x01(\x02\x12\x13\n\x0b\x65xternal_id\x18\t \x01(\t\x12\x14\n\x0cwarehouse_id\x18\n \x01(\x05\x12\x0b\n\x03\x63id\x18\x0b \x01(\t\x12\x36\n\x07\x63ontext\x18\x0c \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13OrderCreateResponse\x12\x35\n\x05order\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xee\x02\n\x10OrderReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11OrderReadResponse\x12\x36\n\x06orders\x18\x01 \x03(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\x83\x01\n\x12OrderUpdateRequest\x12\x35\n\x05order\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13OrderUpdateResponse\x12\x35\n\x05order\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"X\n\x12OrderDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13OrderDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cOrderService\x12z\n\x0bOrderCreate\x12\x33.pro.omni.oms.api.v1.sales.order.OrderCreateRequest\x1a\x34.pro.omni.oms.api.v1.sales.order.OrderCreateResponse"\x00\x12t\n\tOrderRead\x12\x31.pro.omni.oms.api.v1.sales.order.OrderReadRequest\x1a\x32.pro.omni.oms.api.v1.sales.order.OrderReadResponse"\x00\x12z\n\x0bOrderUpdate\x12\x33.pro.omni.oms.api.v1.sales.order.OrderUpdateRequest\x1a\x34.pro.omni.oms.api.v1.sales.order.OrderUpdateResponse"\x00\x12z\n\x0bOrderDelete\x12\x33.pro.omni.oms.api.v1.sales.order.OrderDeleteRequest\x1a\x34.pro.omni.oms.api.v1.sales.order.OrderDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.order_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ORDER"]._serialized_start = 212
    _globals["_ORDER"]._serialized_end = 733
    _globals["_ORDERCREATEREQUEST"]._serialized_start = 736
    _globals["_ORDERCREATEREQUEST"]._serialized_end = 1030
    _globals["_ORDERCREATERESPONSE"]._serialized_start = 1033
    _globals["_ORDERCREATERESPONSE"]._serialized_end = 1184
    _globals["_ORDERREADREQUEST"]._serialized_start = 1187
    _globals["_ORDERREADREQUEST"]._serialized_end = 1553
    _globals["_ORDERREADRESPONSE"]._serialized_start = 1556
    _globals["_ORDERREADRESPONSE"]._serialized_end = 1765
    _globals["_ORDERUPDATEREQUEST"]._serialized_start = 1768
    _globals["_ORDERUPDATEREQUEST"]._serialized_end = 1899
    _globals["_ORDERUPDATERESPONSE"]._serialized_start = 1902
    _globals["_ORDERUPDATERESPONSE"]._serialized_end = 2053
    _globals["_ORDERDELETEREQUEST"]._serialized_start = 2055
    _globals["_ORDERDELETEREQUEST"]._serialized_end = 2143
    _globals["_ORDERDELETERESPONSE"]._serialized_start = 2145
    _globals["_ORDERDELETERESPONSE"]._serialized_end = 2241
    _globals["_ORDERSERVICE"]._serialized_start = 2244
    _globals["_ORDERSERVICE"]._serialized_end = 2748
# @@protoc_insertion_point(module_scope)
