# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.stock import country_pb2 as v1_dot_stock_dot_country__pb2
from omni.pro.protos.v1.stock import location_pb2 as v1_dot_stock_dot_location__pb2
from omni.pro.protos.v1.stock import picking_pb2 as v1_dot_stock_dot_picking__pb2
from omni.pro.protos.v1.stock import picking_type_pb2 as v1_dot_stock_dot_picking__type__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/stock/warehouse.proto\x12#pro.omni.oms.api.v1.stock.warehouse\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17v1/stock/location.proto\x1a\x1bv1/stock/picking_type.proto\x1a\x16v1/stock/country.proto\x1a\x16v1/stock/picking.proto"\xe3\t\n\tWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12;\n\x07\x63ountry\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country\x12\x14\n\x0c\x63ountry_code\x18\x05 \x01(\t\x12:\n\x16territory_matrix_value\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0f\n\x07\x61\x64\x64ress\x18\x07 \x01(\t\x12\x12\n\ncomplement\x18\x08 \x01(\t\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0e\x64\x65livery_steps\x18\n \x01(\t\x12\x17\n\x0freception_steps\x18\x0b \x01(\t\x12\x38\n\x12locality_available\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x43\n\rview_location\x18\r \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12?\n\tloc_stock\x18\x0e \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12H\n\x12wh_input_stock_loc\x18\x0f \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12\x45\n\x0fwh_qc_stock_loc\x18\x10 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12G\n\x11wh_pack_stock_loc\x18\x11 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12I\n\x13wh_output_stock_loc\x18\x12 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12\x44\n\x07in_type\x18\x13 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12\x45\n\x08int_type\x18\x14 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12\x46\n\tpick_type\x18\x15 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12\x46\n\tpack_type\x18\x16 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12\x45\n\x08out_type\x18\x17 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12\x13\n\x0b\x65xternal_id\x18\x18 \x01(\t\x12?\n\x0cobject_audit\x18\x19 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"J\n\tOrderLine\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x17\n\x0fproduct_uom_qty\x18\x02 \x01(\x02\x12\x10\n\x08uom_code\x18\x03 \x01(\t"\xc5\x02\n\x16WarehouseCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12:\n\x16territory_matrix_value\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0f\n\x07\x61\x64\x64ress\x18\x05 \x01(\t\x12\x12\n\ncomplement\x18\x06 \x01(\t\x12\x16\n\x0e\x64\x65livery_steps\x18\x07 \x01(\t\x12\x17\n\x0freception_steps\x18\x08 \x01(\t\x12\x1a\n\x12locality_available\x18\t \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\n \x01(\t\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x17WarehouseCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x41\n\twarehouse\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse"\xf2\x02\n\x14WarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe1\x01\n\x15WarehouseReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x42\n\nwarehouses\x18\x03 \x03(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse"\x93\x01\n\x16WarehouseUpdateRequest\x12\x41\n\twarehouse\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x17WarehouseUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x41\n\twarehouse\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse"\\\n\x16WarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17WarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xe5\x01\n\x13OrderConfirmRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ustomer_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x64\x64ress_code\x18\x04 \x01(\t\x12\x43\n\x0border_lines\x18\x05 \x03(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.OrderLine\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x14OrderConfirmResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12<\n\x08pickings\x18\x02 \x03(\x0b\x32*.pro.omni.oms.api.v1.stock.picking.Picking2\xd8\x05\n\x10WarehouseService\x12\x8e\x01\n\x0fWarehouseCreate\x12;.pro.omni.oms.api.v1.stock.warehouse.WarehouseCreateRequest\x1a<.pro.omni.oms.api.v1.stock.warehouse.WarehouseCreateResponse"\x00\x12\x88\x01\n\rWarehouseRead\x12\x39.pro.omni.oms.api.v1.stock.warehouse.WarehouseReadRequest\x1a:.pro.omni.oms.api.v1.stock.warehouse.WarehouseReadResponse"\x00\x12\x8e\x01\n\x0fWarehouseUpdate\x12;.pro.omni.oms.api.v1.stock.warehouse.WarehouseUpdateRequest\x1a<.pro.omni.oms.api.v1.stock.warehouse.WarehouseUpdateResponse"\x00\x12\x8e\x01\n\x0fWarehouseDelete\x12;.pro.omni.oms.api.v1.stock.warehouse.WarehouseDeleteRequest\x1a<.pro.omni.oms.api.v1.stock.warehouse.WarehouseDeleteResponse"\x00\x12\x85\x01\n\x0cOrderConfirm\x12\x38.pro.omni.oms.api.v1.stock.warehouse.OrderConfirmRequest\x1a\x39.pro.omni.oms.api.v1.stock.warehouse.OrderConfirmResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSE"]._serialized_start = 249
    _globals["_WAREHOUSE"]._serialized_end = 1500
    _globals["_ORDERLINE"]._serialized_start = 1502
    _globals["_ORDERLINE"]._serialized_end = 1576
    _globals["_WAREHOUSECREATEREQUEST"]._serialized_start = 1579
    _globals["_WAREHOUSECREATEREQUEST"]._serialized_end = 1904
    _globals["_WAREHOUSECREATERESPONSE"]._serialized_start = 1907
    _globals["_WAREHOUSECREATERESPONSE"]._serialized_end = 2074
    _globals["_WAREHOUSEREADREQUEST"]._serialized_start = 2077
    _globals["_WAREHOUSEREADREQUEST"]._serialized_end = 2447
    _globals["_WAREHOUSEREADRESPONSE"]._serialized_start = 2450
    _globals["_WAREHOUSEREADRESPONSE"]._serialized_end = 2675
    _globals["_WAREHOUSEUPDATEREQUEST"]._serialized_start = 2678
    _globals["_WAREHOUSEUPDATEREQUEST"]._serialized_end = 2825
    _globals["_WAREHOUSEUPDATERESPONSE"]._serialized_start = 2828
    _globals["_WAREHOUSEUPDATERESPONSE"]._serialized_end = 2995
    _globals["_WAREHOUSEDELETEREQUEST"]._serialized_start = 2997
    _globals["_WAREHOUSEDELETEREQUEST"]._serialized_end = 3089
    _globals["_WAREHOUSEDELETERESPONSE"]._serialized_start = 3091
    _globals["_WAREHOUSEDELETERESPONSE"]._serialized_end = 3191
    _globals["_ORDERCONFIRMREQUEST"]._serialized_start = 3194
    _globals["_ORDERCONFIRMREQUEST"]._serialized_end = 3423
    _globals["_ORDERCONFIRMRESPONSE"]._serialized_start = 3426
    _globals["_ORDERCONFIRMRESPONSE"]._serialized_end = 3585
    _globals["_WAREHOUSESERVICE"]._serialized_start = 3588
    _globals["_WAREHOUSESERVICE"]._serialized_end = 4316
# @@protoc_insertion_point(module_scope)
