# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/query_stock.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1av1/stock/query_stock.proto\x12%pro.omni.oms.api.v1.stock.query_stock\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto"Z\n\x11QueryStockRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x87\x01\n\x12QueryStockResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12&\n\x05query\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct2\x99\x01\n\x11QueryStockService\x12\x83\x01\n\nQueryStock\x12\x38.pro.omni.oms.api.v1.stock.query_stock.QueryStockRequest\x1a\x39.pro.omni.oms.api.v1.stock.query_stock.QueryStockResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.query_stock_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_QUERYSTOCKREQUEST"]._serialized_start = 118
    _globals["_QUERYSTOCKREQUEST"]._serialized_end = 208
    _globals["_QUERYSTOCKRESPONSE"]._serialized_start = 211
    _globals["_QUERYSTOCKRESPONSE"]._serialized_end = 346
    _globals["_QUERYSTOCKSERVICE"]._serialized_start = 349
    _globals["_QUERYSTOCKSERVICE"]._serialized_end = 502
# @@protoc_insertion_point(module_scope)
