# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_price_warehouse_pb2 as v1_dot_rules_dot_delivery__price__warehouse__pb2


class DeliveryPriceWarehouseServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryPriceWarehouseCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService/DeliveryPriceWarehouseCreate",
            request_serializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseCreateResponse.FromString,
        )
        self.DeliveryPriceWarehouseRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService/DeliveryPriceWarehouseRead",
            request_serializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseReadResponse.FromString,
        )
        self.DeliveryPriceWarehouseUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService/DeliveryPriceWarehouseUpdate",
            request_serializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseUpdateResponse.FromString,
        )
        self.DeliveryPriceWarehouseDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService/DeliveryPriceWarehouseDelete",
            request_serializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseDeleteResponse.FromString,
        )


class DeliveryPriceWarehouseServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryPriceWarehouseCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceWarehouseRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceWarehouseUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceWarehouseDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryPriceWarehouseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryPriceWarehouseCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceWarehouseCreate,
            request_deserializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseCreateResponse.SerializeToString,
        ),
        "DeliveryPriceWarehouseRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceWarehouseRead,
            request_deserializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseReadResponse.SerializeToString,
        ),
        "DeliveryPriceWarehouseUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceWarehouseUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseUpdateResponse.SerializeToString,
        ),
        "DeliveryPriceWarehouseDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceWarehouseDelete,
            request_deserializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryPriceWarehouseService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryPriceWarehouseCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService/DeliveryPriceWarehouseCreate",
            v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceWarehouseRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService/DeliveryPriceWarehouseRead",
            v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceWarehouseUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService/DeliveryPriceWarehouseUpdate",
            v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceWarehouseDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price_warehouse.DeliveryPriceWarehouseService/DeliveryPriceWarehouseDelete",
            v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__warehouse__pb2.DeliveryPriceWarehouseDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
